=====================
fijibin API reference
=====================

********************
main module: fijibin
********************
.. automodule:: fijibin
    :members:
    :undoc-members:
    :show-inheritance:


************************
submodule: fijibin.fetch
************************
.. automodule:: fijibin.fetch
    :members:
    :undoc-members:
    :show-inheritance:


************************
submodule: fijibin.macro
************************
.. automodule:: fijibin.macro
    :members:
    :undoc-members:
    :show-inheritance:
